# eric7.Project.IdlCompilerDefineNameDialog

Module implementing a dialog to enter the name-value pair to define a variable for the IDL compiler.

### Global Attributes

None

### Classes

IdlCompilerDefineNameDialog | Class implementing a dialog to enter the name-value pair to define a variable for the IDL compiler.

### Functions

None

## IdlCompilerDefineNameDialog

Class implementing a dialog to enter the name-value pair to define a variable for the IDL compiler.

### Derived from

QDialog, Ui_IdlCompilerDefineNameDialog

### Class Attributes

None

### Class Methods

None

### Methods

IdlCompilerDefineNameDialog | Constructor
__updateOkButton | Private slot to update the enable state of the OK button.
getData | Public method to get the entered data.
on_nameEdit_textChanged | Private slot to handle changes of the name.

### Static Methods

None

#### IdlCompilerDefineNameDialog (Constructor)

IdlCompilerDefineNameDialog(name="", value="", parent=None)

Constructor

name (str)
  name of the variable
value (str)
  value of the variable
parent (QWidget)
  reference to the parent widget

#### IdlCompilerDefineNameDialog.__updateOkButton

__updateOkButton()

Private slot to update the enable state of the OK button.

#### IdlCompilerDefineNameDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the variable name and value

Return Type:
  tuple of (str, str)

#### IdlCompilerDefineNameDialog.on_nameEdit_textChanged

on_nameEdit_textChanged(txt)

Private slot to handle changes of the name.

txt (str)
  current text of the name edit

Up